package com.goldenwater.yjjt.service;

import java.util.List;
import java.util.Map;
import com.goldenwater.yjjt.domain.YjjtSlData;

/**
 * 引江济太水量数据Service接口
 */
public interface IYjjtSlDataService
{
    public YjjtSlData selectYjjtSlDataById(Long id);

    public List<YjjtSlData> selectYjjtSlDataList(YjjtSlData slData);

    public int insertYjjtSlData(YjjtSlData slData);

    public int updateYjjtSlData(YjjtSlData slData);

    public int deleteYjjtSlDataByIds(Long[] ids);

    public int deleteYjjtSlDataById(Long id);

    public List<String> selectDistinctRvnmList();

    public List<Map<String, Object>> selectCountByDateRange(String beginDate, String endDate);

    public Map<String, Object> selectTodayWeekMonthCount(String addvcd);
}
